@@ -1,5 +1,5 @@
 from braintree.sub_merchant_account.address_details import AddressDetails
 from braintree.sub_merchant_account.business_details import BusinessDetails
-from braintree.sub_merchant_account.director_details import DirectorDetails
+from braintree.sub_merchant_account.contact_details import ContactDetails
 from braintree.sub_merchant_account.funding_details import FundingDetails
 from braintree.sub_merchant_account.sub_merchant_account import SubMerchantAccount
